@@ -39,9 +39,7 @@ class Api:
         if not self.manager.notebook_path():
             print("No add done you are in already in naas folder\n")
             return url
-        print(
-            "👌 Well done! Your Notebook has been sent to production folder.\n"
-        )
+        print("👌 Well done! Your Notebook has been sent to production folder.\n")
         print(f"🔑 You can run this notebook remotely with: {url} \n")
         self.manager.copy_url(url)
         print(
