@@ -1,4 +1,3 @@
-from IPython.core.display import display, HTML
 from .types import t_static
 from .manager import Manager
 import os
@@ -63,9 +62,7 @@ class Assets:
         if not self.manager.notebook_path() and Force is False:
             print("No add done you are in already in naas folder\n")
             return url
-        print(
-            "👌 Well done! Your Assets has been sent to production folder.\n"
-        )
+        print("👌 Well done! Your Assets has been sent to production folder.\n")
         print(f"🔗 You can access this assets remotely with: {url} \n")
         self.manager.copy_url(url)
         print(
