@@ -35,19 +35,19 @@ class AssetsController(HTTPMethodView):
             print("Cannot get html error")
             return ""
 
-    def get(self, request, token):
+    async def get(self, request, token):
         if token == "up" or token == "down" or token.startswith("naas_"):
             ext = ".png"
             if token.startswith("naas_"):
                 ext = ".svg"
-            return response.file(
+            return await response.file(
                 os.path.join(
                     self.__path_lib_files, self.__assets_files, f"{token}{ext}"
                 )
             )
         else:
             uid = str(uuid.uuid4())
-            task = self.__jobs.find_by_value(uid, token, t_static)
+            task = await self.__jobs.find_by_value(uid, token, t_static)
             if task:
                 file_filepath = task.get("path")
                 params = task.get("params", dict())
@@ -64,7 +64,7 @@ class AssetsController(HTTPMethodView):
                     self.__jobs.update(
                         uid, file_filepath, t_static, token, params, t_health, 1
                     )
-                    res = response.file(file_filepath)
+                    res = await response.file(file_filepath)
                     self.__logger.info(
                         {
                             "id": uid,
