@@ -12,7 +12,6 @@ from sanic_openapi import swagger_blueprint
 from naas.runner.logger import Logger
 from .proxy import escape_kubernet
 from naas.runner.jobs import Jobs
-from daemonize import Daemonize
 from naas.types import t_main
 from sanic import Sanic
 import sentry_sdk
@@ -22,6 +21,11 @@ import uuid
 import os
 import json
 import sys
+import nest_asyncio
+
+# TODO remove this fix when papermill support uvloop of Sanic support option to don't use uvloop
+asyncio.set_event_loop_policy(None)
+nest_asyncio.apply()
 
 
 class Runner:
@@ -78,7 +82,8 @@ class Runner:
         )
         self.__path_pidfile = os.path.join(self.__path_naas_files, f"{self.__name}.pid")
 
-    def __main(self, debug=False):
+    def __main(self, debug=True):
+        self.init_app()
         uid = str(uuid.uuid4())
         self.__logger.info({"id": uid, "type": t_main, "status": "start API"})
         self.__app.run(host="0.0.0.0", port=self.__port, debug=debug, access_log=debug)
@@ -95,38 +100,30 @@ class Runner:
         return version
 
     async def initialize_before_start(self, app, loop):
-        if self.__nb is None:
-            self.__nb = Notebooks(self.__logger, loop, self.__notif)
-            self.__app.add_route(
-                NbController.as_view(self.__logger, self.__jobs, self.__nb),
-                "/notebooks/<token>",
-            )
-            self.__scheduler = Scheduler(self.__logger, self.__jobs, self.__nb, loop)
-            self.__app.add_route(
-                SchedulerController.as_view(self.__logger, self.__scheduler),
-                "/scheduler/<mode>",
-            )
-            self.__scheduler.start()
-
-    def kill(self):
-        if os.path.exists(self.__path_pidfile):
-            try:
-                with open(self.__path_pidfile, "r") as f:
-                    pid = f.read()
-                    print("kill")
-                    os.system(f"kill {pid}")
-                    print(f"Deamon killed pid {pid}")
-                    f.close()
-            except Exception:
-                print("No Deamon running")
+        self.__jobs = Jobs(self.__logger, loop=loop)
+        self.__nb = Notebooks(self.__logger, loop, self.__notif)
+        self.__app.add_route(
+            NbController.as_view(self.__logger, self.__jobs, self.__nb),
+            "/notebooks/<token>",
+        )
+        self.__scheduler = Scheduler(self.__logger, self.__jobs, self.__nb, loop)
+        self.__app.add_route(
+            SchedulerController.as_view(self.__logger, self.__scheduler),
+            "/scheduler/<mode>",
+        )
+        self.__app.add_route(
+            JobsController.as_view(self.__logger, self.__jobs), "/jobs"
+        )
+        self.__app.add_route(
+            AssetsController.as_view(self.__logger, self.__jobs, self.__path_lib_files),
+            "/assets/<token>",
+        )
+        self.__scheduler.start()
 
     def init_app(self):
+        self.__app = Sanic(__name__)
         self.__logger = Logger()
         self.__notif = Notifications(self.__logger)
-        self.__jobs = Jobs(self.__logger)
-        self.__app = Sanic(__name__)
-        # TODO remove this fix when papermill support uvloop of Sanic support option to don't use uvloop
-        asyncio.set_event_loop_policy(None)
         self.__app.register_listener(
             self.initialize_before_start, "before_server_start"
         )
@@ -142,28 +139,20 @@ class Runner:
             "/env",
         )
         self.__app.add_route(LogsController.as_view(self.__logger), "/logs")
-        self.__app.add_route(
-            JobsController.as_view(self.__logger, self.__jobs), "/jobs"
-        )
-        self.__app.add_route(
-            AssetsController.as_view(self.__logger, self.__jobs, self.__path_lib_files),
-            "/assets/<token>",
-        )
         self.__app.static("/", self.__path_manager_index, name="manager.html")
         self.__app.blueprint(swagger_blueprint)
         uid = str(uuid.uuid4())
         self.__logger.info({"id": uid, "type": t_main, "status": "init API"})
         return self.__app
 
-    def start(self, deamon=True, port=None, debug=True):
+    def start(self, deamon=True, port=None, debug=False):
         user = getpass.getuser()
         if user != self.__shell_user:
             raise Exception(f"{user} not autorized, use {self.__shell_user} instead")
-        self.kill()
         if port:
             self.__port = port
-        self.init_app()
-        if deamon:
+        print("Start Runner")
+        try:
             if os.environ.get("NAAS_SENTRY_DSN"):
                 self.__sentry = sentry_sdk.init(
                     dsn=os.environ.get("NAAS_SENTRY_DSN"),
@@ -171,15 +160,7 @@ class Runner:
                     environment=escape_kubernet(self.__user),
                     integrations=[SanicIntegration()],
                 )
-            self.__daemon = Daemonize(
-                app=self.__name, pid=self.__path_pidfile, action=self.__main
-            )
-            print("Start Runner Deamon Mode")
-            self.__daemon.start()
-        else:
-            print("Start Runner front Mode")
-            try:
-                self.__main(debug)
-            except KeyboardInterrupt:
-                print("Shutdown server")
-                sys.exit()
+            self.__main(debug)
+        except KeyboardInterrupt:
+            print("Shutdown server")
+            sys.exit()
