@@ -34,13 +34,11 @@ class Scheduler:
             return
         cron_string = pretty_cron.prettify_cron(recurrence)
         current_file = self.manager.get_path(path)
+        print("👌 Well done! Your Notebook has been sent to production folder. \n")
         print(
-            "👌 Well done! Your Notebook has been sent to production folder. \n"
-        )
-        print(f'⏰ It will be scheduled "{cron_string}" (more on the syntax on https://crontab.guru/).\n')
-        print(
-            'Ps: to remove the "Scheduler", just replace .add by .delete'
+            f'⏰ It will be scheduled "{cron_string}" (more on the syntax on https://crontab.guru/).\n'
         )
+        print('Ps: to remove the "Scheduler", just replace .add by .delete')
         self.manager.add_prod(
             {
                 "type": self.role,
